[Vtigercrm-commits] [vtiger-commits] r7489 - in /vtigercrm/trunk/include/nusoap: class.nusoap_base.php class.soapclient.php nusoap.php

vtigercrm-commits at vtiger.fosslabs.com vtigercrm-commits at vtiger.fosslabs.com
Sat Jun 24 15:48:22 EDT 2006


Author: mmbrich
Date: Sat Jun 24 13:48:21 2006
New Revision: 7489

Log:
more soap fixes

Modified:
    vtigercrm/trunk/include/nusoap/class.nusoap_base.php
    vtigercrm/trunk/include/nusoap/class.soapclient.php
    vtigercrm/trunk/include/nusoap/nusoap.php

Modified: vtigercrm/trunk/include/nusoap/class.nusoap_base.php
==============================================================================
--- vtigercrm/trunk/include/nusoap/class.nusoap_base.php (original)
+++ vtigercrm/trunk/include/nusoap/class.nusoap_base.php Sat Jun 24 13:48:21 2006
@@ -902,4 +902,4 @@
 }
 
 
-?>
+?>

Modified: vtigercrm/trunk/include/nusoap/class.soapclient.php
==============================================================================
--- vtigercrm/trunk/include/nusoap/nusoap.php (original)
+++ vtigercrm/trunk/include/nusoap/nusoap.php Sat Jun 24 13:48:21 2006
@@ -35,7 +35,7 @@
 /* load classes
 
 // necessary classes
-require_once('class.soapclient2.php');
+require_once('class.soapclient.php');
 require_once('class.soap_val.php');
 require_once('class.soap_parser.php');
 require_once('class.soap_fault.php');





More information about the vtigercrm-commits mailing list
--- vtigercrm/trunk/include/nusoap/class.soapclient.php (original)
+++ vtigercrm/trunk/include/nusoap/class.soapclient.php Sat Jun 24 13:48:21 2006
@@ -5,24 +5,24 @@
 
 /**
 *
 * soapclient higher level class for easy usage.
 *
 * usage:
 *
 * // instantiate client with server info
-* $soapclient = new soapclient( string path [ ,boolean wsdl] );
+* $soapclient2 = new soapclient2( string path [ ,boolean wsdl] );
 *
 * // call method, get results
-* echo $soapclient->call( string methodname [ ,array parameters] );
+* echo $soapclient2->call( string methodname [ ,array parameters] );
 *
 * // bye bye client
-* unset($soapclient);
+* unset($soapclient2);
 *
 * @author   Dietrich Ayala <dietrich at ganx4.com>
-* @version  $Id: class.soapclient.php,v 1.52 2005/07/27 19:24:42 snichol Exp $
+* @version  $Id: class.soapclient2.php,v 1.52 2005/07/27 19:24:42 snichol Exp $
 * @access   public
 */
-class soapclient extends nusoap_base  {
+class soapclient2 extends nusoap_base  {
 
 	var $username = '';
 	var $password = '';
@@ -89,7 +89,7 @@
 	* @param	integer $response_timeout set the response timeout
 	* @access   public
 	*/
-	function soapclient($endpoint,$wsdl = false,$proxyhost = false,$proxyport = false,$proxyusername = false, $proxypassword = false, $timeout = 0, $response_timeout = 30){
+	function soapclient2($endpoint,$wsdl = false,$proxyhost = false,$proxyport = false,$proxyusername = false, $proxypassword = false, $timeout = 0, $response_timeout = 30){
 		parent::nusoap_base();
 		$this->endpoint = $endpoint;
 		$this->proxyhost = $proxyhost;
@@ -669,7 +669,7 @@
 				unset($paramCommentStr);
 			}
 		}
-		$evalStr = 'class soap_proxy_'.$r.' extends soapclient {
+		$evalStr = 'class soap_proxy_'.$r.' extends soapclient2 {
 	'.$evalStr.'
 }';
 		return $evalStr;
@@ -5,24 +5,24 @@
 /**
 *
-* soapclient higher level class for easy usage.
+* soapclient2 higher level class for easy usage.
 *
 * usage:

Modified: vtigercrm/trunk/include/nusoap/nusoap.php
==============================================================================